@@ -1,9 +1,9 @@
 #!/bin/sh
 FGREP="/usr/bin/fgrep"
-SWATP="/opt/samba/sbin/swat"
-PIDIF="/bin/pidof"
-SRVIS="swat		901/tcp"
-INETD="swat	stream	tcp	nowait.400	root	/opt/samba/sbin/swat	swat"
+SWATP="/usr/sbin/swat"
+PIDOF="/bin/pidof"
+SRVIS="swat             901/tcp"
+INETD="swat     stream  tcp     nowait.400      root    /usr/sbin/swat   swat"
 # swat
 if !($FGREP swat /etc/services > /dev/null); then
     echo "$SRVIS" >> /etc/services
@@ -13,4 +13,4 @@ if !($FGREP $SWATP /etc/inetd.conf > /dev/null); then
     echo "$INETD" >> /etc/inetd.conf
 fi
 #
-kill -HUP `$PIDOF inetd`
\ No newline at end of file
+kill -HUP `$PIDOF inetd`
